#
# Conditional build:
%bcond_with	tests		# build without tests

%define		pkgname	phpmailer
%define		php_min_version 5.2.4
Summary:	Full featured email transfer class for PHP
Summary(pl.UTF-8):	W pełni funkcjonalna klasa PHP do przesyłania e-maili
Name:		php-%{pkgname}
Version:	5.2.27
Release:	2
License:	LGPL v2.1
Group:		Development/Languages/PHP
Source0:	https://github.com/PHPMailer/PHPMailer/archive/v%{version}/%{pkgname}-%{version}.tar.gz
# Source0-md5:	a2e45c0fdacea30e4b582b37880ca53e
URL:		https://github.com/PHPMailer/PHPMailer
BuildRequires:	php-devel
BuildRequires:	php-pear-PhpDocumentor
BuildRequires:	rpm-php-pearprov >= 4.4.2-11
BuildRequires:	rpmbuild(macros) >= 1.663
%if %{with tests}
BuildRequires:	%{php_name}-cli
BuildRequires:	%{php_name}-mbstring
BuildRequires:	phpunit
BuildRequires:	which
%endif
Requires:	php(core) >= %{php_min_version}
Requires:	php(ctype)
Requires:	php(date)
Requires:	php(pcre)
Suggests:	php(hash)
Suggests:	php(mbstring)
Suggests:	php(openssl)
Obsoletes:	phpmailer
# Gmail XOAUTH2 authentication
#Suggests:	php-league-oauth2-client
BuildArch:	noarch
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%define		_appdir		%{php_data_dir}/%{pkgname}
%define		_phpdocdir	%{_docdir}/phpdoc

# exclude optional php dependencies
%define		_noautophp	php-openssl php-mbstring php-filter php-hash

# bad depsolver
%define		_noautoreq_pear extras/ntlm_sasl_client.php PHPMailerAutoload.php extras/.*

# put it together for rpmbuild
%define		_noautoreq	%{?_noautophp}

%description
PHP email transport class featuring multiple file attachments, SMTP
servers, CCs, BCCs, HTML messages, and word wrap, and more. It can
send email via sendmail, PHP mail(), or with SMTP. Methods are based
on the popular AspEmail active server component.

%description -l pl.UTF-8
Klasa PHP do przesyłania e-mail obsługująca wiele załączników
plikowych, serwery SMTP, CC, BCC, wiadomości HTML, zawijanie linii
itp. Potrafi wysyłać pocztę przez sendmaila, funkcją PHP mail() albo
poprzez SMTP. Metody są oparte na popularnym komponencie AspEmail.

%package phpdoc
Summary:	Online manual for %{name}
Summary(pl.UTF-8):	Dokumentacja online do %{name}
Group:		Documentation
Requires:	php-dirs

%description phpdoc
Documentation for %{name}.

%description phpdoc -l pl.UTF-8
Dokumentacja do %{name}.

%prep
%setup -q -n PHPMailer-%{version}%{?subver:-%{subver}}

%build
# syntax lint
for f in $(find -name '*.php' -o -name '*.inc'); do

%if "%{php_major_version}.%{php_minor_version}" < "5.4"
	case $(basename $f) in
	class.phpmaileroauthgoogle.php|get_oauth_token.php)
		# needs php 5.4
		continue
	;;
	esac
%endif

%if "%{php_major_version}.%{php_minor_version}" < "5.3"
	case $(basename $f) in
	bootstrap.php|phpmailerTest.php)
		# needs php 5.3
		continue
	;;
	esac
%endif

	%{__php} -n -l $f
done

%if %{with tests}
cd test
%{__php} $(which phpunit) .
cd -
%endif

rm -rf phpdoc
phpdoc --title 'PHPMailer version %{version}' --target phpdoc --defaultpackagename PHPMailer \
	--directory . --ignore test/,examples/,extras/,test_script/,language/,phpdoc/ --sourcecode

# copy images, phpdoc is likely buggy not doing itself
sdir=%{php_pear_dir}/data/PhpDocumentor/phpDocumentor/Converters/HTML/frames/templates/earthli/templates/media/images
install -d phpdoc/media/images
cp -p $sdir/Constant.png phpdoc/media/images
cp -p $sdir/Variable.png phpdoc/media/images

%install
rm -rf $RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT{%{php_data_dir},%{_appdir}/language}

ln -s %{_appdir}/class.phpmailer.php $RPM_BUILD_ROOT%{php_data_dir}
ln -s %{_appdir}/PHPMailerAutoload.php $RPM_BUILD_ROOT%{php_data_dir}

cp -p class.*.php PHPMailerAutoload.php $RPM_BUILD_ROOT%{_appdir}
# language: translations of error messages
cp -p language/*.php $RPM_BUILD_ROOT%{_appdir}/language

# extras: htmlfilter.php, ntlm_sasl_client.php, EasyPeasyICS.php
cp -a extras $RPM_BUILD_ROOT%{_appdir}

# examples
install -d $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}
cp -a examples/* $RPM_BUILD_ROOT%{_examplesdir}/%{name}-%{version}

# api doc
install -d $RPM_BUILD_ROOT%{_phpdocdir}/%{pkgname}
cp -a phpdoc/* $RPM_BUILD_ROOT%{_phpdocdir}/%{pkgname}

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(644,root,root,755)
#%doc README.md changelog.md docs/*
# public interfaces
%{php_data_dir}/PHPMailerAutoload.php
%{php_data_dir}/class.phpmailer.php

%dir %{_appdir}
%{_appdir}/PHPMailerAutoload.php
%{_appdir}/class.phpmailer.php
%{_appdir}/class.phpmaileroauth.php
%{_appdir}/class.phpmaileroauthgoogle.php
%{_appdir}/class.pop3.php
%{_appdir}/class.smtp.php
%dir %{_appdir}/language
%lang(am) %{_appdir}/language/phpmailer.lang-am.php
%lang(ar) %{_appdir}/language/phpmailer.lang-ar.php
%lang(az) %{_appdir}/language/phpmailer.lang-az.php
%lang(ba) %{_appdir}/language/phpmailer.lang-ba.php
%lang(be) %{_appdir}/language/phpmailer.lang-be.php
%lang(bg) %{_appdir}/language/phpmailer.lang-bg.php
%lang(ca) %{_appdir}/language/phpmailer.lang-ca.php
%lang(ch) %{_appdir}/language/phpmailer.lang-ch.php
%lang(cs) %{_appdir}/language/phpmailer.lang-cs.php
%lang(da) %{_appdir}/language/phpmailer.lang-da.php
%lang(de) %{_appdir}/language/phpmailer.lang-de.php
%lang(el) %{_appdir}/language/phpmailer.lang-el.php
%lang(eo) %{_appdir}/language/phpmailer.lang-eo.php
%lang(es) %{_appdir}/language/phpmailer.lang-es.php
%lang(et) %{_appdir}/language/phpmailer.lang-et.php
%lang(fa) %{_appdir}/language/phpmailer.lang-fa.php
%lang(fi) %{_appdir}/language/phpmailer.lang-fi.php
%lang(fo) %{_appdir}/language/phpmailer.lang-fo.php
%lang(fr) %{_appdir}/language/phpmailer.lang-fr.php
%lang(gl) %{_appdir}/language/phpmailer.lang-gl.php
%lang(he) %{_appdir}/language/phpmailer.lang-he.php
%lang(hr) %{_appdir}/language/phpmailer.lang-hr.php
%lang(hu) %{_appdir}/language/phpmailer.lang-hu.php
%lang(id) %{_appdir}/language/phpmailer.lang-id.php
%lang(it) %{_appdir}/language/phpmailer.lang-it.php
%lang(ja) %{_appdir}/language/phpmailer.lang-ja.php
%lang(ka) %{_appdir}/language/phpmailer.lang-ka.php
%lang(ko) %{_appdir}/language/phpmailer.lang-ko.php
%lang(lt) %{_appdir}/language/phpmailer.lang-lt.php
%lang(lv) %{_appdir}/language/phpmailer.lang-lv.php
%lang(ms) %{_appdir}/language/phpmailer.lang-ms.php
%lang(nb) %{_appdir}/language/phpmailer.lang-nb.php
%lang(nl) %{_appdir}/language/phpmailer.lang-nl.php
%lang(pl) %{_appdir}/language/phpmailer.lang-pl.php
%lang(pt) %{_appdir}/language/phpmailer.lang-pt.php
%lang(pt_BR) %{_appdir}/language/phpmailer.lang-pt_br.php
%lang(ro) %{_appdir}/language/phpmailer.lang-ro.php
%lang(rs) %{_appdir}/language/phpmailer.lang-rs.php
%lang(ru) %{_appdir}/language/phpmailer.lang-ru.php
%lang(sk) %{_appdir}/language/phpmailer.lang-sk.php
%lang(sl) %{_appdir}/language/phpmailer.lang-sl.php
%lang(sv) %{_appdir}/language/phpmailer.lang-sv.php
%lang(tr) %{_appdir}/language/phpmailer.lang-tr.php
%lang(uk) %{_appdir}/language/phpmailer.lang-uk.php
%lang(vi) %{_appdir}/language/phpmailer.lang-vi.php
%lang(zh) %{_appdir}/language/phpmailer.lang-zh.php
%lang(zh_CN) %{_appdir}/language/phpmailer.lang-zh_cn.php

%dir %{_appdir}/extras
%{_appdir}/extras/README.md
%{_appdir}/extras/EasyPeasyICS.php
%{_appdir}/extras/htmlfilter.php
%{_appdir}/extras/ntlm_sasl_client.php

%{_examplesdir}/%{name}-%{version}

%files phpdoc
%defattr(644,root,root,755)
%{_phpdocdir}/%{pkgname}
%changelog
* Sat Mar 21 2020 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/php-phpmailer.git;a=log;h=master

* Sat Mar 21 2020 Jan Rękorajski <baggins@pld-linux.org> f45fe9d
- release 2 (by relup.sh)

* Sat Jan 25 2020 Jan Rękorajski <baggins@pld-linux.org> c4afa3d
- drop obsolete and outdated manual inclusion of rpm macros

* Thu Jan 17 2019 Elan Ruusamäe <glen@pld-linux.org> c457dd8
- up to 5.2.27; disallows urls in addAttachment; CVE-2018-19296 fix

* Tue Nov 14 2017 Elan Ruusamäe <glen@pld-linux.org> 73d2a81
- up to 5.2.26 (November 4th 2017)

* Tue Nov 14 2017 Elan Ruusamäe <glen@pld-linux.org> 06c3789
- up to 5.2.25 (August 28th 2017)

* Tue Nov 14 2017 Elan Ruusamäe <glen@pld-linux.org> d5c3878
- up to 5.2.24 (July 26th 2017)

* Mon Mar 27 2017 Elan Ruusamäe <glen@delfi.ee> 29ecff3
- up to 5.2.23

* Mon Jan 09 2017 Elan Ruusamäe <glen@delfi.ee> 2ba7e3f
- CVE-2017-5223: update to 5.2.22

* Wed Dec 28 2016 Elan Ruusamäe <glen@delfi.ee> 91a9c48
- requires ctype ext

* Wed Dec 28 2016 Arkadiusz Miśkiewicz <arekm@maven.pl> 4c8a0a8
- up to 5.2.21; fixes CVE-2016-10045

* Tue Dec 27 2016 Elan Ruusamäe <glen@delfi.ee> efa2c2b
- no more documentation in source tarball

* Tue Dec 27 2016 Elan Ruusamäe <glen@delfi.ee> 6b46fa0
- translation changes

* Tue Dec 27 2016 Elan Ruusamäe <glen@delfi.ee> e51d3a5
- Version 5.2.19 (December 26th 2016)

* Tue Dec 27 2016 Elan Ruusamäe <glen@delfi.ee> 03ab47a
- Version 5.2.18 (December 24th 2016); SECURITY

* Tue Dec 27 2016 Elan Ruusamäe <glen@delfi.ee> e7bb53d
- Version 5.2.17 (December 9th 2016)

* Fri Sep 16 2016 Elan Ruusamäe <glen@delfi.ee> 5ed6149
- Version 5.2.16 (June 6th 2016)

* Fri Sep 16 2016 Elan Ruusamäe <glen@delfi.ee> da5b78f
- Version 5.2.15 (May 10th 2016)

* Thu Feb 25 2016 Elan Ruusamäe <glen@delfi.ee> 0893ce7
- Version 5.2.14 (Nov 1st 2015)

* Thu Sep 17 2015 Elan Ruusamäe <glen@delfi.ee> 47134f6
- Version 5.2.13 (Sep 14th 2015)

* Fri Sep 04 2015 Elan Ruusamäe <glen@delfi.ee> db04397
- BR php-devel virtual

